{% extends "base.html" %}

{% block title %}
  Search {{ super() }}
{% endblock title %}

{% block extra_head %}
  <script src="https://cdnjs.cloudflare.com/ajax/libs/jquery/3.5.1/jquery.min.js" integrity="sha512-bLT0Qm9VnAYZDflyKcBaQ2gg0hSYNQrJ8RilYldYQ1FxQYoCLtUjuuRuZo+fjqhx/qtq/1itJ0C2ejDxltZVFg==" crossorigin="anonymous"></script>
  <script src="/tipuesearch_content.js"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/Tipue-Search/5.0.0/tipuesearch_set.js" integrity="sha512-IeL4E/+Y3qyhmKBvZnLTIt6njLLIvi8x1PiUnQAnEYOQwuvoXtP/C/qgJjOrO5x8v2YrxwvXlLCKkxlb04bTog==" crossorigin="anonymous"></script>
  <script src="https://cdnjs.cloudflare.com/ajax/libs/Tipue-Search/5.0.0/tipuesearch.js" integrity="sha512-RW1nayqEDgxbGmDv7Dh4D1yDvyCYM9ELHJN2zCLBQefJqyafeEL42UEKuOFh1JgoF6Juy2tXFy7uT2kCtX+ANQ==" crossorigin="anonymous"></script>
  <!--<script src="https://cdnjs.cloudflare.com/ajax/libs/Tipue-Search/5.0.0/tipuesearch.min.js" integrity="sha512-PcsSgY/THO2pCv9wOPo/81CTpcsOYKRxbADV27uu0t1Tx4cp288Obp6hdcLZ4flJYrATYEOGQn0ujIjyOu7Dfg==" crossorigin="anonymous"></script>-->
  <script>
    $(document).ready(function() {
      $('#tipue_search_input').tipuesearch({
          'show': 10,
          'descriptiveWords': 75,
          'showURL': false,
          'newWindow': false,
      });
    });
  </script>
{% endblock %}

{% block content %}
<h1>Search</h1>
<form action="/search/" class="search" method="get">
    <input type="text" name="q" id="tipue_search_input">
</form>

<div>
    <div id="tipue_search_content"></div>
</div>
{% endblock content %}
