from _typeshed import Incomplete
from xmldiff import diff as diff
from xmldiff import formatting as formatting
from xmldiff import patch as patch

FORMATTERS: Incomplete

def diff_trees(
    left,
    right,
    diff_options: Incomplete | None = ...,
    formatter: Incomplete | None = ...,
): ...
def diff_texts(
    left,
    right,
    diff_options: Incomplete | None = ...,
    formatter: Incomplete | None = ...,
): ...
def diff_files(
    left,
    right,
    diff_options: Incomplete | None = ...,
    formatter: Incomplete | None = ...,
): ...
def make_diff_parser(): ...
def diff_command(args: Incomplete | None = ...) -> None: ...
def patch_tree(actions, tree): ...
def patch_text(actions, tree): ...
def patch_file(actions, tree): ...
def make_patch_parser(): ...
def patch_command(args: Incomplete | None = ...) -> None: ...
