from collections.abc import Generator

from _typeshed import Incomplete

def post_order_traverse(node) -> Generator[Incomplete, None, None]: ...
def reverse_post_order_traverse(node) -> Generator[Incomplete, None, None]: ...
def breadth_first_traverse(node) -> Generator[Incomplete, None, None]: ...
def longest_common_subsequence(left_sequence, right_sequence, eqfn=...): ...

WHITESPACE: Incomplete

def cleanup_whitespace(text): ...
def getpath(element, tree: Incomplete | None = ...): ...
def make_ascii_tree(element): ...
