*,
*:before,
*:after {
  box-sizing: border-box;
}

body {
    header {
        text-align: center;

        h1 {
            a {
                text-decoration: none;
                &:visited {
                    text-decoration: none;
                }
                &:hover {
                    text-decoration: none;
                }
            }
        }
    }

    nav {
        max-width: 40rem;
        //margin: 0 auto;
        text-align: center;
    }

    main {
        h1 {
            margin-bottom: 0.5em;
        }
        ul {
            margin-top: 0.5em;
        }
    }
}

ol#post-list {
  list-style: none;
  padding: 0;
  li {
    margin-bottom: 3em;
  }
}

.latex sub, .latex sup {
  text-transform: uppercase;
  font-size: 1em;
}

.latex sub {
  font-size: 1em;
}

.latex sup {
  font-size: 0.8em;
  vertical-align: 0.2em;
  margin-left: -0.42em;
  margin-right: -0.15em;
}

pre {
  position: relative;
  overflow: auto;

  /* make space  */
  margin: 5px 0;
  padding: 1.75rem 0 1.75rem 1rem;
  border-radius: 10px;
}

pre button {
  position: absolute;
  top: 5px;
  right: 5px;

  font-size: 0.9rem;
  padding: 0.15rem;
  background-color: #828282;

  border: ridge 1px #7b7b7c;
  border-radius: 5px;
  text-shadow: #c4c4c4 0 0 2px;
}

pre button:hover {
  cursor: pointer;
  background-color: #bcbabb;
}


/*
Tipue Search 5.0
Copyright (c) 2015 Tipue
Tipue Search is released under the MIT License
http://www.tipue.com/search
*/

#tipue_search_input
{
     font: 13px/1.6;
	color: #333;
	padding: 12px 12px 12px 40px;
	width: 170px;
	border: 1px solid #e2e2e2;
	border-radius: 0;
	-moz-appearance: none;
	-webkit-appearance: none;
     box-shadow: none;
	outline: 0;
	margin-top: 1em;
	box-sizing: unset;
	background: #fff url('https://cdnjs.cloudflare.com/ajax/libs/Tipue-Search/5.0.0/img/search.png') no-repeat 15px 15px;
}

#tipue_search_content
{
     max-width: 650px;
	padding-top: 15px;
	margin: 0;
}
#tipue_search_warning
{
     font: 300 15px/1.6;
	color: #555;
	margin: 7px 0;
}
#tipue_search_warning a
{
     color: #396;
     text-decoration: none;
}
#tipue_search_warning a:hover
{
     color: #555;
}
#tipue_search_results_count
{
     font: 300 15px/1.7;
	//color: #555;
}
.tipue_search_content_title
{
     font: 300 21px/1.7;
	margin-top: 23px;
}
.tipue_search_content_title a
{
     //color: #333;
     text-decoration: none;
}
.tipue_search_content_title a:hover
{
     //color: #555;
}
.tipue_search_content_url
{
     font: 300 14px/1.9;
     word-wrap: break-word;
     hyphens: auto;
}
.tipue_search_content_url a
{
     //color: #396;
     text-decoration: none;
}
.tipue_search_content_url a:hover
{
     //color: #555;
}
.tipue_search_content_text
{
     font: 300 15px/1.6;
	//color: #555;
     word-wrap: break-word;
     hyphens: auto;
     margin-top: 3px;
}
.tipue_search_content_debug
{
     font: 300 13px/1.6;
	//color: #555;
     margin: 5px 0;
}
.h01
{
     //color: #333;
     font-weight: 400;
}

#tipue_search_foot
{
     margin: 51px 0 21px 0;
}
#tipue_search_foot_boxes
{
	padding: 0;
	margin: 0;
     font: 12px 'Open Sans', sans-serif; font-family: inherit;
}
#tipue_search_foot_boxes li
{
	list-style: none;
	margin: 0;
	padding: 0;
	display: inline;
}
#tipue_search_foot_boxes li a
{
	padding: 10px 17px 11px 17px;
     background-color: #fff;
     border: 1px solid #e2e2e2;
     border-radius: 1px;
	//color: #333;
	margin-right: 7px;
	text-decoration: none;
	text-align: center;
}
#tipue_search_foot_boxes li.current
{
	padding: 10px 17px 11px 17px;
     background: #f6f6f6;
     border: 1px solid #e2e2e2;
     border-radius: 1px;
	//color: #333;
	margin-right: 7px;
	text-align: center;
}
#tipue_search_foot_boxes li a:hover
{
     background: #f6f6f6;
}


/* spinner */


.tipue_search_spinner
{
     padding: 31px 0;
     width: 50px;
     height: 28px;
}
.tipue_search_spinner > div
{
     background-color: #777;
     height: 100%;
     width: 3px;
     display: inline-block;
     margin-right: 2px;
     -webkit-animation: stretchdelay 1.2s infinite ease-in-out;
     animation: stretchdelay 1.2s infinite ease-in-out;
}
.tipue_search_spinner .tipue_search_rect2
{
     -webkit-animation-delay: -1.1s;
     animation-delay: -1.1s;
}
.tipue_search_spinner .tipue_search_rect3
{
     -webkit-animation-delay: -1.0s;
     animation-delay: -1.0s;
}
@-webkit-keyframes stretchdelay
{
     0%, 40%, 100%
     {
          -webkit-transform: scaleY(0.4)
     }
     20%
     {
          -webkit-transform: scaleY(1.0)
     }
}
@keyframes stretchdelay
{
     0%, 40%, 100%
     {
          transform: scaleY(0.4);
          -webkit-transform: scaleY(0.4);
     }
     20%
     {
          transform: scaleY(1.0);
          -webkit-transform: scaleY(1.0);
     }
}
